16.40. cdist-type__docker(7) — cdist 6.9.4 documentation

# 16.40. cdist-type__docker(7)

## 16.40.1. NAME

cdist-type__docker - install Docker CE

## 16.40.2. DESCRIPTION

Installs latest Docker Community Edition package.

## 16.40.3. REQUIRED PARAMETERS

None.

## 16.40.4. OPTIONAL PARAMETERS

state

  'present' or 'absent', defaults to 'present'

version

  The specific version to install. Defaults to the special value 'latest', meaning the version the package manager will install by default.

## 16.40.5. BOOLEAN PARAMETERS

None.

## 16.40.6. EXAMPLES

    # Install docker
    __docker

    # Remove docker
    __docker --state absent

    # Install specific version
    __docker --state present --version 18.03.0.ce

## 16.40.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.40.8. COPYING

Copyright (C) 2016 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).